# makefile                                                              #
# --------------------------------------------------------------------- #
# Compendium - C++ Container Class Library                              #
# Copyright (C) 1992-1994, Glenn M. Poorman, All rights reserved        #
# --------------------------------------------------------------------- #
# Makefile for building Compendium on supported Unix platforms.         #
#                                                                       #
# Usage: make - Build archive library "libcm.a"                         #
# --------------------------------------------------------------------- #

# Set operating system name in OS variable.
OS = $(shell echo `/bin/uname -s`)

# Set non platform specific variables.
VPATH   = ../../source
INCLUDE = ../../..
LIB     = libcm.a
OBJS    = \
cmarray.o \
cmassoc.o \
cmbag.o \
cmbdict.o \
cmbintr.o \
cmbtree.o \
cmcont.o \
cmdate.o \
cmdeque.o \
cmhash.o \
cmhdict.o \
cmiter.o \
cmlist.o \
cmobject.o \
cmobjref.o \
cmordarr.o \
cmqueue.o \
cmreserv.o \
cmresfil.o \
cmring.o \
cmset.o \
cmstack.o \
cmstring.o \
cmtime.o \
cmtokens.o

# Set operating system dependant variables.

# Hewlett Packard HP-UX
ifeq ($(OS),HP-UX)
  CC        = CC
  CCFLAGS   = -c -I$(INCLUDE)
  TFLAGS    = -pta
  TOBJS     = ptrepository/*.o
  MAKEMAIN  = echo "void main() {}" > cmmain.cxx
  BUILDMAIN = $(CC) -o cmmain $(TFLAGS) -I$(INCLUDE) cmmain.cxx *.o
endif

# Sun Solaris
ifeq ($(OS),SunOS)
  CC        = CC
  CCFLAGS   = -c -I$(INCLUDE)
  TFLAGS    = -pta
  TOBJS     = ptrepository/*.o
  MAKEMAIN  = echo "void main() {}" > cmmain.cxx
  BUILDMAIN = $(CC) -o cmmain $(TFLAGS) -I$(INCLUDE) cmmain.cxx *.o
endif

# Silicon Graphics IRIX
ifeq ($(OS),IRIX)
  CC        = CC
  CCFLAGS   = -c -I$(INCLUDE)
  TFLAGS    = -pta -pte.cc
  TOBJS     = ptrepository/*.o
  MAKEMAIN  = echo "void main() {}" > cmmain.cxx
  BUILDMAIN = $(CC) -o cmmain $(TFLAGS) -I$(INCLUDE) cmmain.cxx *.o
endif

# IBM AIX
ifeq ($(OS),AIX)
  CC        = xlC
  CCFLAGS   = -+ -c -I$(INCLUDE)
  TFLAGS    =
  TOBJS     =
  MAKEMAIN  =
  BUILDMAIN =
endif

# Build archive library.
$(LIB): $(OBJS)
        rm -f $(LIB)
        $(MAKEMAIN)
        $(BUILDMAIN)
        ar qv $(LIB) $(OBJS) $(TOBJS)
        chmod 600 *.o $(LIB)
        rm -f cmmain cmmain.cxx

# Build individual object file. 
%.o:    $(VPATH)/%.cxx
        $(CC) $(CCFLAGS) -o $@ $(VPATH)/$*.cxx

# Clean up object and library files.
clean:
        rm -rf *.o $(LIB) ptrepository

